==> hs-syb-0.3.tgz: lib/ghc/syb-0.3/register.sh <==
#!/bin/sh
echo 'name: syb
version: 0.3
id: syb-0.3-8db7bc4339a1cb8a6f2a46c40447ef0b

license: BSD3
copyright:
maintainer: generics@haskell.org
stability: provisional
homepage: http://www.cs.uu.nl/wiki/GenericProgramming/SYB
package-url:
description: This package contains the generics system described in the
             /Scrap Your Boilerplate/ papers (see
             <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
             It defines the @Data@ class of types permitting folding and unfolding
             of constructor applications, instances of this class for primitive
             types, and a variety of traversals.
category: Generics
author: Ralf Lammel, Simon Peyton Jones
pkgpath: devel/hs-syb
exposed: True
exposed-modules: Data.Generics Data.Generics.Basics
                 Data.Generics.Instances Data.Generics.Aliases Data.Generics.Schemes
                 Data.Generics.Text Data.Generics.Twins Data.Generics.Builders
                 Generics.SYB Generics.SYB.Basics Generics.SYB.Instances
                 Generics.SYB.Aliases Generics.SYB.Schemes Generics.SYB.Text
                 Generics.SYB.Twins Generics.SYB.Builders
hidden-modules:
import-dirs: /usr/local/lib/ghc/syb-0.3
library-dirs: /usr/local/lib/ghc/syb-0.3
hs-libraries: HSsyb-0.3
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.3.1.0-912d55d387093f740e3bcd2ffbf1dd83
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-syb-0.3/html/syb.haddock
haddock-html: /usr/local/share/doc/hs-syb-0.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-syb-0.3.3.tgz: lib/ghc/syb-0.3.3/register.sh <==
#!/bin/sh
echo 'name: syb
version: 0.3.3
id: syb-0.3.3-dd575fa8180bf87dbbe1727117c3b35c

license: BSD3
copyright:
maintainer: generics@haskell.org
stability: provisional
homepage: http://www.cs.uu.nl/wiki/GenericProgramming/SYB
package-url:
description: This package contains the generics system described in the
             /Scrap Your Boilerplate/ papers (see
             <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
             It defines the @Data@ class of types permitting folding and unfolding
             of constructor applications, instances of this class for primitive
             types, and a variety of traversals.
category: Generics
author: Ralf Lammel, Simon Peyton Jones
pkgpath: devel/hs-syb
exposed: True
exposed-modules: Data.Generics Data.Generics.Basics
                 Data.Generics.Instances Data.Generics.Aliases Data.Generics.Schemes
                 Data.Generics.Text Data.Generics.Twins Data.Generics.Builders
                 Generics.SYB Generics.SYB.Basics Generics.SYB.Instances
                 Generics.SYB.Aliases Generics.SYB.Schemes Generics.SYB.Text
                 Generics.SYB.Twins Generics.SYB.Builders
hidden-modules:
import-dirs: /usr/local/lib/ghc/syb-0.3.3
library-dirs: /usr/local/lib/ghc/syb-0.3.3
hs-libraries: HSsyb-0.3.3
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-syb-0.3.3/html/syb.haddock
haddock-html: /usr/local/share/doc/hs-syb-0.3.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
